"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBackportBranchName = void 0;
const commitFormatters_1 = require("../github/commitFormatters");
/*
 * Returns the name of the backport branch without remote name
 *
 * Examples:
 * For a single PR: `backport/7.x/pr-1234`
 * For a single commit: `backport/7.x/commit-abcdef`
 * For multiple: `backport/7.x/pr-1234_commit-abcdef`
 */
function getBackportBranchName(targetBranch, commits) {
    const refValues = commits
        .map((commit) => commit.sourcePullRequest
        ? `pr-${commit.sourcePullRequest.number}`
        : `commit-${(0, commitFormatters_1.getShortSha)(commit.sourceCommit.sha)}`)
        .join('_')
        .slice(0, 200);
    return `backport/${targetBranch}/${refValues}`;
}
exports.getBackportBranchName = getBackportBranchName;
//# sourceMappingURL=getBackportBranchName.js.map